##  Prerequisites
  * An SAP BTP subaccount that is configured to trust your IAS tenant, and with a Cloud Foundry environment configured.
  * Administrative access to your IAS tenant.
  * Trusted certificate authentication must be enabled in IAS for this tenant, as described in [Configure X.509 Client Certificates for User Authentication](https://help.sap.com/docs/cloud-identity-services/cloud-identity-services/configure-x-509-client-certificates-for-user-authentication "https://help.sap.com/docs/cloud-identity-services/cloud-identity-services/configure-x-509-client-certificates-for-user-authentication").
When you configure this, select Distinguished Name as the source. Create a certificate pattern that uniquely matches the X.509 client certificate LeanIX will use. You will later add the certificate pattern generated by LeanIX to this configuration.
